@@ -1,9 +1,9 @@
 /***************************************************************************
-                          mediacontrol.cpp  -  main file of the applet
+                        main file of mediacontrol applet
                              -------------------
     begin                : Tue Apr 25 11:53:11 CEST 2000
-    copyright            : (C) 2000-2003 by Stefan Gehn
-    email                : sgehn@gmx.net
+    copyright            : (C) 2000-2005 by Stefan Gehn
+    email                : metz {AT} gehn {DOT} net
  ***************************************************************************/
 
 /***************************************************************************
@@ -30,6 +30,7 @@
 #include "xmmsInterface.h"
 #include "jukInterface.h"
 #include "amarokInterface.h"
+#include "mpdInterface.h"
 #include "kscdInterface.h"
 
 #include "mcslider.h"
@@ -51,8 +52,8 @@
 #include <kbugreport.h>
 #include <dcopclient.h>
 
-const int MC_BUTTONSIZE=18; // TODO: Might become dynamical for bigger panels
-const int NO_BUTTONS=4;
+const int MC_BUTTONSIZE = 18; // TODO: Might become dynamical for bigger panels
+const int NO_BUTTONS = 4;
 
 extern "C"
 {
@@ -128,6 +129,8 @@ MediaControl::MediaControl(const QString &configFile, Type t, int actions,
 		"teemu.rytilahti@kde-fi.org", 0);
 	mAboutData->addCredit("Jan Spitalnik", I18N_NOOP("Fix for JuK-Support"),
 		"honza@spitalnik.net", 0);
+	mAboutData->addCredit("William Robinson", I18N_NOOP("mpd-Support"),
+		"airbaggins@yahoo.co.uk", 0);
 
 	setAcceptDrops(true);
 
@@ -152,7 +155,6 @@ MediaControl::MediaControl(const QString &configFile, Type t, int actions,
 	rmbMenu->insertItem(SmallIcon("configure"), i18n("Configure MediaControl..."),
 		this, SLOT(preferences()));
 	rmbMenu->insertItem(i18n("About MediaControl"), this, SLOT(about()));
-
 }
 
 MediaControl::~MediaControl()
@@ -328,9 +330,9 @@ void MediaControl::reparseConfig()
 //	kdDebug(90200) << "reparseConfig();" << endl;
 	_configFrontend->reparseConfiguration();
 
-	if ( _player != 0L ) // make sure there is no player-object
+	if (_player != 0L) // make sure there is no player-object
 	{
-		_player->disconnect();	// disconnect from all things
+		_player->disconnect(); // disconnect from all things
 
 		time_slider->disconnect();
 		prev_button->disconnect();
@@ -379,6 +381,12 @@ void MediaControl::reparseConfig()
 		time_slider->setSteps((_configFrontend->mouseWheelSpeed()),
 			(_configFrontend->mouseWheelSpeed()));
 	}
+	else if (playerString == "mpd")
+	{
+		_player = new MpdInterface();
+		time_slider->setSteps((_configFrontend->mouseWheelSpeed()),
+			(_configFrontend->mouseWheelSpeed()));
+	}
 	else // Fallback is Noatun
 	{
 		_player = new NoatunInterface();
