@@ -1,9 +1,9 @@
 /***************************************************************************
-                noatuninterface.cpp  -  Interface to access Noatun
+                          Interface to access Noatun
                              -------------------
     begin                : Mon Jan 15 21:09:00 CEST 2001
     copyright            : (C) 2000-2002 by Stefan Gehn
-    email                : sgehn@gmx.net
+    email                : metz {AT} gehn {DOT} net
  ***************************************************************************/
 
 /***************************************************************************
@@ -269,9 +269,9 @@ bool NoatunInterface::findRunningNoatun()
 {
 	// FIXME: what if we have a dcop app named, let's say, 'noatunfrontend'?
 	QCStringList allApps = kapp->dcopClient()->registeredApplications();
-	QValueList<QCString>::iterator iterator;
+	QValueList<QCString>::const_iterator iterator;
 
-	for (iterator = allApps.begin(); iterator != allApps.end(); iterator++)
+	for (iterator = allApps.constBegin(); iterator != allApps.constEnd(); ++iterator)
 	{
 		if ((*iterator).contains("noatun", false))
 		{
