@@ -273,7 +273,10 @@ void ArkMenu::compMimeTypes()
         if ( havegz )
             m_archiveMimeTypes << "application/x-tgz";
         if ( havebz2 )
+        {
             m_archiveMimeTypes << "application/x-tbz";
+            m_archiveMimeTypes << "application/x-tbz2";
+        }
         if ( havelzop )
             m_archiveMimeTypes << "application/x-tzo";
     }
@@ -290,7 +293,7 @@ void ArkMenu::compMimeTypes()
     }
 
     if ( !KStandardDirs::findExe( "rar" ).isNull() && m_conf->readBoolEntry( "UseRar", true ) )
-        m_archiveMimeTypes << "application/x-rar";
+        m_archiveMimeTypes << "application/x-rar" << "application/x-rar-compressed";
 
     if ( !KStandardDirs::findExe( "zoo" ).isNull() && m_conf->readBoolEntry( "UseZoo", false ) )
         m_archiveMimeTypes << "application/x-zoo";
@@ -335,7 +338,10 @@ void ArkMenu::extMimeTypes()
         if ( havegz )
             m_extractMimeTypes << "application/x-tgz";
         if ( havebz2 )
+        {
             m_extractMimeTypes << "application/x-tbz";
+            m_extractMimeTypes << "application/x-tbz2";
+        }
         if ( havelzop )
             m_extractMimeTypes << "application/x-tzo";
     }
@@ -347,7 +353,7 @@ void ArkMenu::extMimeTypes()
         m_extractMimeTypes << "application/x-zip" << "application/x-jar";
 
     if ( !KStandardDirs::findExe( "unrar" ).isNull() )
-        m_extractMimeTypes << "application/x-rar";
+        m_extractMimeTypes << "application/x-rar" << "application/x-rar-compressed";
 
     if ( !KStandardDirs::findExe( "zoo" ).isNull() )
         m_extractMimeTypes << "application/x-zoo";
