@@ -14,8 +14,8 @@ Library General Public License for more details.
 
 You should have received a copy of the GNU Library General Public License
 along with this library; see the file COPYING.LIB.  If not, write to
-the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-Boston, MA 02111-1307, USA.
+the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+Boston, MA 02110-1301, USA.
 */
 
 #include <qdir.h>
@@ -27,6 +27,7 @@ Boston, MA 02111-1307, USA.
 #include <qimage.h>
 #include <qprogressdialog.h>
 #include <qtextcodec.h>
+#include <qstylesheet.h>
 
 #include <kaction.h>
 #include <kglobal.h>
@@ -117,22 +118,23 @@ bool KImGalleryPlugin::createDirectory(QDir thumb_dir, QString imgGalleryDir, QS
 
 void KImGalleryPlugin::createHead(QTextStream& stream)
 {
-    QString chsetName = QTextCodec::codecForLocale()->mimeName();
+    const QString chsetName = QTextCodec::codecForLocale()->mimeName();
 
     stream << "<?xml version=\"1.0\" encoding=\"" +  chsetName + "\" ?>" << endl;
     stream << "<!DOCTYPE html PUBLIC \"-//W3C//DTD XHTML 1.1//EN\" \"http://www.w3.org/TR/xhtml11/DTD/xhtml11.dtd\">" << endl;
     stream << "<html xmlns=\"http://www.w3.org/1999/xhtml\">" << endl;
     stream << "<head>" << endl;
-    stream << "<title>" << m_configDlg->getTitle() << "</title>" << endl;
+    stream << "<title>" << QStyleSheet::escape(m_configDlg->getTitle()) << "</title>" << endl;
     stream << "<meta http-equiv=\"content-type\" content=\"text/html; charset=" << chsetName << "\"/>" << endl;
+    stream << "<meta name=\"GENERATOR\" content=\"KDE Konqueror KImgallery plugin version " KDE_VERSION_STRING "\"/>" << endl;
     createCSSSection(stream);
     stream << "</head>" << endl;
 }
 
 void KImGalleryPlugin::createCSSSection(QTextStream& stream)
 {
-    QString backgroundColor = m_configDlg->getBackgroundColor().name();
-    QString foregroundColor = m_configDlg->getForegroundColor().name();
+    const QString backgroundColor = m_configDlg->getBackgroundColor().name();
+    const QString foregroundColor = m_configDlg->getForegroundColor().name();
     //adding a touch of style
     stream << "<style type='text/css'>\n";
     stream << "BODY {color: " << foregroundColor << "; background: " << backgroundColor << ";" << endl;
@@ -146,14 +148,14 @@ void KImGalleryPlugin::createCSSSection(QTextStream& stream)
 }
 
 
-/*static*/ QString KImGalleryPlugin::extension(const QString& imageFormat)
+QString KImGalleryPlugin::extension(const QString& imageFormat)
 {
 	if (imageFormat == "PNG")
 		return ".png";
 	if (imageFormat == "JPEG")
 		return ".jpg";
 	Q_ASSERT(false);
-	return "";
+	return QString::null;
 }
 
 void KImGalleryPlugin::createBody(QTextStream& stream, const QString& sourceDirName, const QStringList& subDirList,
@@ -163,7 +165,7 @@ void KImGalleryPlugin::createBody(QTextStream& stream, const QString& sourceDirN
     const QString imgGalleryDir = url.directory();
     const QString today(KGlobal::locale()->formatDate(QDate::currentDate()));
 
-    stream << "<body>\n<h1>" << m_configDlg->getTitle() << "</h1><p>" << endl;
+    stream << "<body>\n<h1>" << QStyleSheet::escape(m_configDlg->getTitle()) << "</h1><p>" << endl;
     stream << i18n("<i>Number of images</i>: %1").arg(numOfImages) << "<br/>" << endl;
     stream << i18n("<i>Created on</i>: %1").arg(today) << "</p>" << endl;
 
@@ -222,12 +224,12 @@ void KImGalleryPlugin::createBody(QTextStream& stream, const QString& sourceDirN
 
             if (m_configDlg->printImageSize()) {
                 imginfo.setFile( imageDir, imgName );
-                stream << "<div>(" << (imginfo.size() / 1024) << " " <<  i18n("KB") << ") " << "</div>" << endl;
+                stream << "<div>(" << (imginfo.size() / 1024) << " " <<  i18n("KB") << ")" << "</div>" << endl;
             }
 
             if (m_useCommentFile) {
                 QString imgComment = (*m_commentMap)[imgName].local8Bit();
-                stream << "<div>" << imgComment << "</div>" << endl;
+                stream << "<div>" << QStyleSheet::escape(imgComment) << "</div>" << endl;
             }
             stream << "</td>" << endl;
 
@@ -389,9 +391,9 @@ void KImGalleryPlugin::loadCommentFile()
             curLine = m_textStream->readLine();
             curLineStripped = curLine.stripWhiteSpace();
             // Lines starting with '#' are comment
-            if (!(curLineStripped.isEmpty()) && !(curLineStripped.left(1)=="#")) {
-                if (curLineStripped.right(1)==":") {
-                    picComment = "";
+            if (!(curLineStripped.isEmpty()) && !curLineStripped.startsWith("#")) {
+                if (curLineStripped.endsWith(":")) {
+                    picComment = QString::null;
                     picName = curLineStripped.left(curLineStripped.length()-1);
                     kdDebug(90170) << "picName: " << picName << endl;
                 } else {
@@ -400,7 +402,7 @@ void KImGalleryPlugin::loadCommentFile()
                         picComment += curLine + "\n";
                         curLine = m_textStream->readLine();
                     } while (!m_textStream->eof() && !(curLine.stripWhiteSpace().isEmpty()) &&
-                             !(curLine.stripWhiteSpace().left(1)=="#"));
+                             !curLine.stripWhiteSpace().startsWith("#"));
                     //kdDebug(90170) << "Pic comment: " << picComment << endl;
                     m_commentMap->insert(picName, picComment);
                 }
